pub struct AppApi {
pub provision: ProvisionMode,
pub port: Option<u16>,
pub redirect_port: Option<u16>,
pub insecure: bool,
pub insecure_cookies: bool,
pub log_ttl_hours: u16,
pub log_rotation_file_size: u64,
pub log_rotation_mins: u16,
pub log_headers: bool,
pub log_ips: bool,
pub redacted_header_hash: String,
pub danger_dns_no_verify: bool,
}Fields
provision: ProvisionModewhat mode TLS certs should be provisioned in
port: Option<u16>specify HTTP(s) port for server
redirect_port: Option<u16>specify HTTP port for server when running in secure mode.
insecure: boolrun without HTTPS
run with insecure cookies
log_ttl_hours: u16max period of time logs are stored
log_rotation_file_size: u64max size (in bytes) per log file
log_rotation_mins: u16max amount of time a log file is appended to before being compressed and stored
log_headers: boolwhether HTTP request and response headers are logged
log_ips: boolwhether IP Addresses are logged with HTTP requests
redacted_header_hash: String“none” | “blake2” | “blake3”
danger_dns_no_verify: boolset to true to bypass verification of proxy domain and CNAME
DNS TXT records.
IMPORTANT: should ONLY be used for local development and testing.